# Changelog

## [stormi-v0.2.3](https://github.com/pinellolab/stormi/compare/stormi-v0.2.2...stormi-v0.2.3) (2025-03-25)

### Bug Fixes

* **pyproject:** refactor preprocessing deps to optional group ([5c0fb47](https://github.com/pinellolab/stormi/commit/5c0fb4740a97d0a129914d90a308a0c1edda88f4))
* **pyproject:** set version lower bounds for conda compatibility ([4dbfe5c](https://github.com/pinellolab/stormi/commit/4dbfe5c4151190255889a5e278a8c1546c7af8df))
